<?php
/**
 * Main popular Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add Main popular enable section
$wp_customize->add_section( 'kids_education_pro_popular_section', array(
	'title'             => esc_html__( 'Popular','kids-education-pro' ),
	'description'       => esc_html__( 'Popular section options. Recommended image size for popular is 1350px by 550px', 'kids-education-pro' ),
	'priority'			=> '10',
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add Main popular enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[enable_popular]', array(
	'default'           => $options['enable_popular'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[enable_popular]', array(
	'label'             => esc_html__( 'Check To Enable', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_popular_section',
	'type'              => 'select',
	'choices'			=> kids_education_pro_enable_disable_options(),
) );

$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_title]', array(
	'default'           => $options['popular_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[popular_title]', array(
	'label'           	=> esc_html__( 'Title', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_popular_section',
	'type'            	=> 'text',
	'active_callback' 	=> 'kids_education_pro_is_popular_active',
) );

// Add Main popular content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_type]', array(
	'default'           => $options['popular_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[popular_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_popular_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_popular_active',
	'choices'         	=> array(
		'category'		=> esc_html__( 'Category', 'kids-education-pro' ),
		'post'			=> esc_html__( 'Post', 'kids-education-pro' ),
		'page'			=> esc_html__( 'Page', 'kids-education-pro')	
	)
) );

// Add Main popular number of posts setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_no_of_posts]', array(
	'default'           => $options['popular_no_of_posts'],
	'validate_callback' => 'kids_education_pro_validate_no_of_popular',
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[popular_no_of_posts]', array(
	'label'           	=> esc_html__( 'Number Of popular Post', 'kids-education-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects.', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_popular_section',
	'active_callback' 	=> 'kids_education_pro_is_popular_active',
	'type'            	=> 'number',
	'input_attrs'		=> array(
		'min'			=> '2',
		'max'			=> '10',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

// Add Main popular category drop-down setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_category_type]', array(		
	'sanitize_callback'	=> 'kids_education_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Kids_Education_Pro_Dropdown_Category_Control( $wp_customize, 'kids_education_pro_theme_options[popular_category_type]', array(
	'active_callback' 	=> 'kids_education_pro_is_popular_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_popular_section',
	'type'            	=> 'dropdown-category',
 ) ) );


$value = kids_education_pro_get_theme_options();
$no_of_post = $value['popular_no_of_posts'];

for ( $i = 1; $i <= $no_of_post; $i++ ) {
	// Insert main popular  post id
	$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_post_id_' . $i . ']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[popular_post_id_' . $i . ']', array(
		'label'             => esc_html__( 'Post id # ' , 'kids-education-pro' ) . $i,
		'section'           => 'kids_education_pro_popular_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'kids-education-pro' ) ),
		'type'              => 'number',
		'active_callback'	=> 'kids_education_pro_is_popular_content_as_post'
	) );

	// Select main popular page
	$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_page_id_' . $i . ']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[popular_page_id_' . $i . ']', array(
		'label'             => esc_html__( 'Select Page # ' , 'kids-education-pro' ) . $i,
		'section'           => 'kids_education_pro_popular_section',
		'active_callback'	=> 'kids_education_pro_is_popular_content_as_page',
		'type'              => 'dropdown-pages',
	) );
}

$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_learn_more_text]', array(
	'default'           => $options['popular_learn_more_text'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[popular_learn_more_text]', array(
	'label'           	=> esc_html__( 'Learn More Text', 'kids-education-pro' ),
	'description'		=> esc_html__( 'Leave empty to hide button', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_popular_section',
	'active_callback' 	=> 'kids_education_pro_is_popular_active',
));


$wp_customize->add_setting( 'kids_education_pro_theme_options[popular_excerpt]', array(
	'default'           => $options['popular_excerpt'],
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[popular_excerpt]', array(
	'label'           	=> esc_html__( 'Expcerpt Lenght', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_popular_section',
	'active_callback' 	=> 'kids_education_pro_is_popular_active',
	'type'            	=> 'number',
) );