<?php
/**
 * cta section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_cta_section' ) ) :
  /**
   * Add cta section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_cta_section() {

    // Check if cta is enabled on frontpage
    $cta_enable = apply_filters( 'kids_education_pro_section_status', true, 'enable_cta_content' );
    if ( true !== $cta_enable ) {
      return false;
    }

    // Get cta section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_cta_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render cta section now.
    kids_education_pro_render_cta_section( $section_details );
  }
endif;

$options = kids_education_pro_get_theme_options();
if ( $options['site_design'] == 'fifth-design' ) {
   add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_cta_section', 40 );
}



if ( ! function_exists( 'kids_education_pro_get_cta_section_details' ) ) :
  /**
   * cta section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input cta section details.
   */
  function kids_education_pro_get_cta_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();


    $content = array();

          $id = null;
          if ( isset( $options[ 'cta_page_id' ] ) ) {
              $id = $options[ 'cta_page_id' ];
          }
          if ( ! empty( $id ) ) {
              $id = absint( $id );
          }
          // Bail if no valid pages are selected.
          if ( empty( $id ) ) {
              return $input;
          }

          $args = array(
              'post_type'      => 'page',
              'p'              => $id,
          );


      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          foreach ( $posts as $key => $post ) {
            $page_id = $post->ID;

            $img_array = null;

                if ( has_post_thumbnail( $page_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'large' );
                } else {
                        $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-1350x550.jpg' );
                }

                if ( isset( $img_array ) ) {
                    $content['img_array'] = $img_array;
                }
            $content['url']      = get_permalink( $page_id );
            $content['title']    = get_the_title( $page_id );
            $content['content']  = kids_education_pro_trim_content( $options['cta_excerpt'], $post );
            $content['read_more_text'] = $options['cta_learn_more_text'];
          }
      }


    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// cta section content details.
add_filter( 'kids_education_pro_filter_cta_section_details', 'kids_education_pro_get_cta_section_details' );


if ( ! function_exists( 'kids_education_pro_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_cta_section( $content_details = array() ) {
        $options          = kids_education_pro_get_theme_options();
        if ( empty( $content_details ) ) {
          return;
        } ?>
        <div id="medical-cta" class="relative page-section" style="background-image: url('<?php echo esc_url( $content_details['img_array'][0] ); ?>');">
               <div class="overlay"></div>
                <div class="container">
                    <div class="medical-cta-wrapper">
                        <div class="section-header">
                            <p class="section-subtitle"><?php echo esc_html( $options['cta_subtitle'] ); ?></p>
                            <h2 class="section-title"><?php echo esc_html( $content_details['title'] ); ?></h2>
                        </div><!-- .section-header -->
                        <div class="entry-content">
                            <p><?php echo esc_html( $content_details['content'] ); ?></p> 
                        </div><!-- .entry-content -->

                        <div class="medical-read-more">
                             <a href="<?php echo esc_url( $content_details['url'] ); ?>"><?php echo esc_html( $content_details['read_more_text'] ); ?></a>
                        </div>
                    </div>
                </div><!-- .wrapper -->
        </div>       
<?php 
    }
endif;