<?php
/**
 * gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_gallery_section' ) ) :
  /**
   * Add gallery section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_gallery_section() {

    // Check if gallery is enabled on frontpage
    $gallery_enable = apply_filters( 'kids_education_pro_section_status', true, 'gallery_enable' );
    if ( true !== $gallery_enable ) {
      return false;
    }

    // Get gallery section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_gallery_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render gallery section now.
    kids_education_pro_render_gallery_section( $section_details );
  }
endif;

$options = kids_education_pro_get_theme_options();
if ( in_array( $options['site_design'] , array( 'classic-design', 'modern-design', 'third-design' ) ) ) {
    add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_gallery_section', 80 );
}



if ( ! function_exists( 'kids_education_pro_get_gallery_section_details' ) ) :
  /**
   * gallery section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input gallery section details.
   */
  function kids_education_pro_get_gallery_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();

    // gallery type
    $gallery_content_type  = $options['gallery_source'];

    $content = array();
    switch ( $gallery_content_type ) {
      case 'demo':
        $terms = array( 'activities events songs', 'photos programs songs', 'activities events photos', 'activities programs', 'events photos songs videos', 'photos', 'activities songs videos', 'events programs songs videos' );
        for ( $i=1; $i<=8; $i++ ) {
          $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/gallery-0'.$i.'.jpg';
          $content[$i]['img_array_large'][0] = get_template_directory_uri() . '/assets/uploads/gallery-0'.$i.'.jpg';
          $content[$i]['url']          = '#';
          $content[$i]['title']        = esc_html__( 'ACTIVITIES', 'kids-education-pro' );
          $content[$i]['alt']          = esc_html__( 'Photo galllery', 'kids-education-pro' );
          $content[$i]['terms']        = $terms[$i-1]; // start index from 0
        }
      break;

      case 'category':
        $cat_ids = '';
        if ( !empty( $options['gallery_category'] ) ) {
            $cat_ids = $options['gallery_category'];
        }

        // Bail if no valid pages are selected.
        if ( empty( $cat_ids ) ) {
            return $input;
        }

        $args = array(
            'category__in'   => $cat_ids,
            'post_type'      => 'post',
            'posts_per_page' => absint( $options['gallery_no_of_img'] ),
            'order'          => 'ASC',
            'orderby'        => 'rand',
        );
      break;

      default:
      break;
    }

    if ( 'demo' != $gallery_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( !empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
              $page_id = $post->ID;
              $img_array = null;
              $img_array_large = null;
            if ( has_post_thumbnail( $page_id ) ) {
                $img_array       = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'kids-education-pro-gallery-section-small' );
                $img_array_large = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
            } else {
                $img_array[0]       =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.png';
                $img_array_large[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-625x400.png';
            }

            $content[$i]['img_array']       = $img_array;
            $content[$i]['img_array_large'] = $img_array_large;
            $content[$i]['url']             = get_permalink( $page_id );
            $content[$i]['title']           = get_the_title( $page_id );
            $content[$i]['alt']             = get_the_title( $page_id );
            $content[$i]['terms']           = get_the_category( $page_id );

            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// gallery section content details.
add_filter( 'kids_education_pro_filter_gallery_section_details', 'kids_education_pro_get_gallery_section_details' );


if ( ! function_exists( 'kids_education_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_gallery_section( $content_details = array() ) {

        if ( empty( $content_details ) ) {
          return;
        } 
        
        $options               = kids_education_pro_get_theme_options();
        $content_type          = $options['gallery_source'];
        $gallery_title         = !empty( $options['gallery_title'] ) ? $options['gallery_title'] : '';
        $gallery_description   = !empty( $options['gallery_description'] ) ? $options['gallery_description'] : '';
        $gallery_category_ids  = !empty( $options['gallery_category'] ) ? $options['gallery_category'] : array();
        $gallery_readmore_text = !empty( $options['gallery_page_readmore'] ) ? $options['gallery_page_readmore'] : '';
        $gallery_readmore_link = !empty( $options['gallery_page_link'] ) ? get_permalink( $options['gallery_page_link'] ) : '#';

        $background_property = $options['gallery_background_property'];
        $background_css      = !empty( $options['gallery_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['gallery_background_image'] ) .')"' : '';

        if( 'background_color' == $background_property ){
          $background_css = !empty( $options['gallery_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['gallery_background_color'] ) .'"' : '';
        }
        ?>
        <section id="portfolio-gallery" class="page-section move-section-up background-image-properties os-animation" data-os-animation="fadeIn" <?php echo $background_css; ?>>
            <div class="container">
                <?php if( !empty( $gallery_title ) || !empty( $gallery_description ) ): ?>
                <header class="entry-header">
                <?php if( !empty( $gallery_title ) ){ ?>
                <h2 class="entry-title"><?php echo esc_html( $gallery_title );?></h2>
                <?php } 
                if( !empty( $gallery_description ) ){ ?>
                <p class="sub-title"><?php echo esc_html( $gallery_description ); ?></p>
                <?php } ?>
                </header><!-- .entry-header -->
                <?php endif; ?>

                <div class="entry-content">
                    <nav class="portfolio-filter">
                        <ul>
                        <?php if( 'demo' == $content_type ) : ?>
                            <li class="active"><a href="#" data-filter="*"><?php esc_html_e( 'Filter all', 'kids-education-pro' ); ?></a></li>
                            <li><a href="#" data-filter=".activities"><?php esc_html_e( 'Activities', 'kids-education-pro' ); ?></a></li>
                            <li><a href="#" data-filter=".events"><?php esc_html_e( 'Events', 'kids-education-pro' ); ?></a></li>
                            <li><a href="#" data-filter=".photos"><?php esc_html_e( 'Photos', 'kids-education-pro' ); ?></a></li>
                            <li><a href="#" data-filter=".programs"><?php esc_html_e( 'Programs', 'kids-education-pro' ); ?></a></li>
                            <li><a href="#" data-filter=".songs"><?php esc_html_e( 'Songs', 'kids-education-pro' ); ?></a></li>
                            <li><a href="#" data-filter=".videos"><?php esc_html_e( 'Videos', 'kids-education-pro' ); ?></a></li>
                          <?php else :
                            echo '<li class="active"><a href="#" data-filter="*">'. esc_html__( 'Filter all', 'kids-education-pro' ) .'</a></li>';
                            foreach ( $gallery_category_ids as $gallery_category_id ) {
                                $tp_category = get_category( $gallery_category_id );
                                echo '<li><a href="#" data-filter=".' . esc_attr( $tp_category->slug ) . '">' . esc_html( $tp_category->name ) . '</a></li>';
                            }
                          endif;
                          ?>
                        </ul>
                    </nav><!-- .portfolio-filter -->

                    <div id="four-col" class="portfolio-wrapper">
                    <?php foreach ($content_details as $content_detail ) { 

                        if( 'demo' == $content_type ){
                            $tab_name = $content_detail['terms'];
                        } else{
                            $categories = $content_detail['terms'];
                            $tab_name = '';
                            foreach ( $categories as $category ) {
                              $tab_name .= $category->slug . ' ';
                            }
                        }
                        ?>

                        <div class="portfolio-item <?php echo esc_attr( $tab_name );?>">
                            <div class="image-wrapper">
                              <img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content_detail['alt'] );?>">
                              <div class="blue-overlay"></div>
                            </div><!-- .image-wrapper -->
                            <div class="hovercontent">
                              <a data-title="Gallery" href="<?php echo esc_url( $content_detail['img_array_large'][0] ); ?>" data-lightbox="masonry"><i class="fa fa-search"></i></a>
                              <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><i class="fa fa-link"></i></a>
                              <p><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></p>
                            </div><!-- end .hover-content -->
                        </div><!-- end .portfolio-item -->

                    <?php } ?>              
                    </div><!-- end portfolio -->

                    <?php if( 'demo' == $content_type ):?>
                        <div class="text-center">
                            <a href="#" class="btn btn-blue"><?php esc_html_e('Load More', 'kids-education-pro' );?></a>
                        </div>
                    <?php else:
                    if( !empty( $gallery_readmore_text ) ){ ?>
                        <div class="text-center">
                            <a href="<?php echo esc_url( $gallery_readmore_link ); ?>" class="btn btn-blue"><?php echo esc_html( $gallery_readmore_text ); ?></a>
                        </div><!-- end .text-center -->
                    <?php }
                    endif; ?>

                </div><!-- end .entry-content -->

            </div><!-- end .container -->
        </section><!-- #portfolio-gallery -->
<?php 
    }
endif;