<?php
/**
 * Map Shortcode Widget
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

if ( ! class_exists( 'Kids_Education_Pro_Map_Shortcode' ) ) :
	/**
	 * Map Shortcode class.
	 *
	 * @since Kids Education Pro 1.0
	 */
	class Kids_Education_Pro_Map_Shortcode extends WP_Widget {
		/**
		 * Sets up the widgets name etc
		 */
		public function __construct() {
			$widget_ops = array(
				'classname'   => 'widget_map',
				'description' => esc_html__( 'Enter Shortcode from Plugin.', 'kids-education-pro' ),
			);
			parent::__construct( 'kids_education_pro_map_shortcode',esc_html__( 'TP : Map Shortcode','kids-education-pro' ), $widget_ops );
		}

		/**
		 * Outputs the content of the widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			// outputs the content of the widget
			if ( ! isset( $args['widget_id'] ) ) {
				$args['widget_id'] = $this->id;
			}

			$title 	= ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';

			$map_shortcode  = ! empty( $instance['map_shortcode'] ) ? $instance['map_shortcode'] : '';

   			echo $args['before_widget'];
				if ( ! empty( $title ) ) {
					echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
				}
				if( !empty( $map_shortcode ) ){
					echo '<div id="map">';
					echo do_shortcode( $map_shortcode );
					echo '</div>';
				}
			echo $args['after_widget'];
		}

		/**
		 * Outputs the options form on admin
		 *
		 * @param array $instance The widget options
		 */
		public function form( $instance ) {
			$title     	= isset( $instance['title'] ) ? ( $instance['title'] ) : '' ;
			$map_shortcode 	= isset( $instance['map_shortcode'] ) ? $instance['map_shortcode'] : '';
		   ?>

		   <p>
			   <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'kids-education-pro' ); ?></label>
			   <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		   </p>

		   <p>
		   	<label for="<?php echo esc_attr( $this->get_field_id( 'map_shortcode' ) ); ?>"><?php esc_html_e( 'Enter shortcode:', 'kids-education-pro' ); ?></label>
		   	<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'map_shortcode' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'map_shortcode' ) ); ?>" value="<?php echo esc_attr( $map_shortcode ); ?>"/>
		   </p>

		   <?php
		}

		/**
		* Processing widget options on save
		*
		* @param array $new_instance The new options
		* @param array $old_instance The previous options
		*/
		public function update( $new_instance, $old_instance ) {
			// processes widget options to be saved
			$instance           			= $old_instance;
			$instance['title']  			= sanitize_text_field( $new_instance['title'] );
			$instance['map_shortcode']      = sanitize_text_field ( $new_instance['map_shortcode'] );

			return $instance;
		}
	}
endif;

function kids_education_pro_register_map_shortcode() {
	register_widget( 'Kids_Education_Pro_Map_Shortcode' );
}
add_action( 'widgets_init', 'kids_education_pro_register_map_shortcode' );